Frederik_hclust: Hierarchical Clustering Algorithm

View source: R/Frederik_hclust.R

Frederik_hclustR Documentation

Hierarchical Clustering Algorithm

Description

Computes clusterings for a dataset via the hierarchical clustering method

Usage

Frederik_hclust(matrix_of_data, target_nr_of_clusters)

Arguments

matrix_of_data

the input dataset. Must be a purely numeric matrix [observations x dimentions]

target_nr_of_clusters

the desired number of clusters

Value

a vector of length [observations] showing clusterings for all datapoints in the input data matrix

Examples

data_set = as.matrix(iris[, -5])
Frederik_hclust(data_set, 3)

FrederikGantzel/FrederikClusteringAlgorithms documentation built on June 14, 2022, 11:42 p.m.