View source: R/Frederik_hclust.R
| Frederik_hclust | R Documentation |
Computes clusterings for a dataset via the hierarchical clustering method
Frederik_hclust(matrix_of_data, target_nr_of_clusters)
matrix_of_data |
the input dataset. Must be a purely numeric matrix [observations x dimentions] |
target_nr_of_clusters |
the desired number of clusters |
a vector of length [observations] showing clusterings for all datapoints in the input data matrix
data_set = as.matrix(iris[, -5]) Frederik_hclust(data_set, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.